import React from 'react';
import ReactDOM from 'react-dom';

import apiUrls from '../../apiUrls'

import Switcher from './Switcher.jsx';
import Loading from '../loading.gif';

class Stat extends React.Component {

    render() {
        let txstat = [<div className="stat-header" key={'Tx-header'}>TX statistics</div>];
        txstat.push(this.props.item['TX statistic'].map(
            (item, index) => <div key={'Tx' + index}> { item } </div>
        ));
        let rxstat = [<div className="stat-header" key={'Rx-header'}>RX statistics</div>];
        rxstat.push(this.props.item['RX statistic'].map(
            (item, index) => <div key={'Rx' + index}> { item } </div>
        ));
        let classstat = [<div className="stat-header" key={'Cs-header'}>Classificator statistics</div>];
        classstat.push(this.props.item['Classificator statistic'].map(
            (item, index) => <div key={'Cs' + index}> { item } </div>
        ));
        let bytesstat = [<div className="stat-header" key={'Bs-header'}>Bytes statistics</div>];
        bytesstat.push(this.props.item['Bytes statistic'].map(
            (item, index) => <div key={'Bs' + index}> {item} </div>
        ));
        return (
            <div align="center">
                <div style={{'display': 'inline-block', verticalAlign: 'top', width: '25%', minWidth: 'max-content'}}>{ txstat }</div>
                <div style={{'display': 'inline-block', verticalAlign: 'top', width: '25%', minWidth: 'max-content'}}>{ rxstat }</div>
                <div style={{'display': 'inline-block', verticalAlign: 'top', width: '25%', minWidth: 'max-content'}}>{ classstat }</div>
                <div style={{'display': 'inline-block', verticalAlign: 'top', width: '25%', minWidth: 'max-content'}}>{ bytesstat }</div>
            </div>
        )
    }
}

class EmStat extends React.Component {

    constructor(props) {
        super(props);
        this.state = {isLoading: true, activeEMAC: 1};
    }

    load = () => {
        fetch(
            apiUrls.emstat,
            { credentials: 'include' }
        ).then(
            (body) => body.json()
        ).then(
            (json) => {
                return this.setState({isLoading: false, emStatList: json});
            }
        );
    };

    componentDidMount(){
        this.load();
        this.interval = setInterval(() => this.load(), 5000);
    }

    componentDidUpdate(){
        ReactDOM.render(
            <div className="switcher">
                <Switcher name="EMAC" entriesNumber={16} startPoint={1} activePort={this.state.activeEMAC} setActive={this.setActive}/>
            </div>,
            document.getElementById('id_menu'),
        );
    }

    setActive = (emac) => {
        this.setState({activeEMAC: emac});
    };

    handleClean = (e) => {
        if (e.target.name === 'clean') {
            this.sendR(this.state.activeEMAC)
        }else {
            this.sendR(-1)
        }
        this.load();
    };

    sendR = (flag) => {
        let toSend;
        if(flag === -1){
            toSend = '{}';
        }else {
            toSend = '{"EMAC_ID" : "' + flag + '"}';
        }
        fetch(
            apiUrls.emstat,
            {
                method: 'POST',
                credentials: 'include',
                body: toSend,
                headers: {
                    'X-CSRFToken': getCSRF(),
                    'content-type': 'application/json',
                }
            }).then(
            body => body.json(),
        ).then(
            json => console.log(json)
        );
    };

    render() {
        if (this.state.isLoading) {
            return (
                <div> <img src={ Loading } className={'loading-img'} id={this.props.name + 'loading-img'}/></div>
            );
        }

        return (
            <div>
                <Stat item={this.state.emStatList[this.state.activeEMAC - 1]}/><br/>
                <button name="clean" onClick={this.handleClean}>Clean</button><br/>
                <button name="clean_all" onClick={this.handleClean}>Clean All</button>
            </div>
        )
    }

}

class EmStat1 extends React.Component {

    constructor(props) {
        super(props);
        this.state = {isLoading: true, active: [true]};
    }

    onChange = (e) => {
        this.setState({[e.target.name]: e.target.value});
    };


    load = () => {
        fetch(
            apiUrls.emstat,
            { credentials: 'include' }
        ).then(
            (body) => body.json()
        ).then(
            (json) => {
                return this.setState({isLoading: false, statList: json});
            }
        );
    };


    componentDidMount(){
        this.load();
        this.interval = setInterval(() => this.load(), 5000);
    }

    render() {
        if (this.state.isLoading) {
            return (
                <div> <img src={ Loading } className={'loading-img'} id={this.props.name + 'loading-img'}/></div>
            );
        }
        const emStat = this.state.statList.map(
            item => {
                return (
                    <Stat key={ item.EMAC_ID } item={item}/>
                )
            }
        );
        return (
            <div>{ emStat }</div>
        )
    }

}



ReactDOM.render(
    <EmStat />,
    document.getElementById('id_content'),
);
