import React from 'react';
import ReactDOM from 'react-dom';

import apiUrls from '../../apiUrls'
import Popup from "./Popup.jsx";
import Loading from '../loading.gif';

class MacRecord extends React.Component {

    render(){
        return(
            <tbody>
                <tr align="center">
                    <td>{ this.props.index }</td>
                    <td>{ this.props.item.VLANID }</td>
                    <td>{ this.props.item.MAC }</td>
                    <td>{ this.props.item.Freshbit }</td>
                    <td>{ this.props.item.Type }</td>
                    <td>{ this.props.item.Action }</td>
                    <td>{ this.props.item.Port }</td>
                    <td>
                        <button
                            className="button-delete"
                            onClick={this.props.onDelete }
                            name={
                                this.props.item.VLANID +
                                '_' + this.props.item.MAC
                            }
                        >
                        </button>
                    </td>
                </tr>
            </tbody>
        )
    }
}

class MacTable extends React.Component {

    constructor(props){
        super(props);
        this.state = {
            isLoading: true,
        }
    }

    deleteAll = (isOk, e) => {
        if(isOk === true){
            let bodyStr = '{"DELETE_ID": ' + (e === undefined ? "-1" : '"' + e.name + '"' )+ '}';
            console.log(bodyStr);
            fetch(
                apiUrls.macs,
                {
                    method: 'POST',
                    credentials: 'include',
                    body: bodyStr,
                    headers: {
                        'X-CSRFToken': getCSRF(),
                        'content-type': 'application/json',
                    }
                }).then(
                body => body.json(),
            ).then(
                (json) => {
                    console.log(json);
                    this.setState({isLoading: true});
                    this.load()
                }
            );
        }
    };

    onDelete = (e) => {
        let isOk = false;
        if (e.target.name === '-1') {
            isOk = confirm('Delete ALL MAC entries?');
            this.deleteAll(isOk);
        } else {
            isOk = confirm('Delete ' + e.target.name.split("_")[1] + ' entry?');
            this.deleteAll(isOk, e.target);
        }
    };

    load = () => {
        fetch(
            apiUrls.macs,
            { credentials: 'include' }
        ).then(
            (body) => body.json()
        ).then(
            (json) => {
                return this.setState({isLoading: false, macList: json});
            }
        );
    };

    componentDidMount(){
        this.load();
    }

    render(){
        if (this.state.isLoading) {
            return (
                <div> <img src={ Loading } className={'loading-img'} id={this.props.name + 'loading-img'}/></div>
            );
        }
        console.log(this.state.macList);
        if(!(
            typeof this.state.macList !== "undefined" &&
            this.state.macList !== null &&
            this.state.macList.length !== null &&
            this.state.macList.length > 0)
        ) {
            return (
                <div>Table is empty.</div>
            );
        }

        const macs = this.state.macList.map(
            (item, index) => <MacRecord index={index + 1} key={item.MAC} item={ item } onDelete={this.onDelete}/>

        );
        return (
            <div align="center">
                <table border="1">
                    <tbody>
                        <tr align="center">
                            <td style={{'minWidth': '25px'}}>#</td>
                            <td>VLANID</td>
                            <td>MAC</td>
                            <td>Fresh bit</td>
                            <td>Type</td>
                            <td>Action</td>
                            <td>Port</td>
                            <td>Delete</td>
                        </tr>
                    </tbody>
                    { macs }
                </table>
                <button onClick={ this.onDelete } name="-1">Delete all</button>
            </div>
        );
    }
}

ReactDOM.render(
    <MacTable />,
    document.getElementById('id_content'),
);
