import React from 'react';
import ReactDOM from 'react-dom';

import apiUrls from '../../apiUrls';

import Switcher from './Switcher.jsx';
import Loading from '../loading.gif';

class OnePortSettings extends React.Component {

    handleChange = (e) => {
        e.target.className += (e.target.classList.contains('changed') ?  '' : 'changed');

        let port = this.activePort;
        let settings = this.props.settings;
        settings[e.target.name] = e.target.value;
        this.props.onChange(port, settings);
    };

    handleSubmit  = (e) => {
        e.preventDefault();
        if (this.isValid(e)) {
            this.props.onClick(this.props.activePort);
        }
    };

    isValid = (e) => {
        let elems = e.target.form.getElementsByClassName('changed');
        let validity = true;
        for (let i = 0; i < elems.length; i++){
            if(!elems[i].validity.valid){
                validity = false;
            }
        }
        console.log(elems);
        if (!validity) {
            alert('You have invalid fields!');
            return false;
        }
        return true;
    };

    render() {
        return (
            <form method="POST">
                <div className="port-settings"  align="center">
                    <table>
                        <tbody>
                            <tr>
                                <td className="stat-td" style={{'textAlign': 'right'}}>
                                    <label className="left">TPID </label>
                                    <input
                                        title={'Format: FFFF\nIn most case use: 8100'}
                                        pattern="^[0-9a-fA-F]{4}$"
                                        value={this.props.settings.TPID}
                                        name="TPID"
                                        onChange={ this.handleChange }
                                        required
                                    /><br/>

                                    <label className="left">Fallback_BD_id (dec)</label>&nbsp;
                                    <input
										type="number"
										min="0"
										max="4095"
										value={this.props.settings["Fallback_BD_id (dec)"]}
                                        name="Fallback_BD_id (dec)"
                                        onChange={ this.handleChange }
                                        min="0"
                                        required
                                    /><br/>

                                    <label className="left">shutdown</label>&nbsp;
                                    <select name="shutdown" value={this.props.settings.shutdown} onChange={ this.handleChange }>
                                        <option value="0">Working / Turn on</option>
                                        <option value="1">Disabled / Turn off </option>
                                    </select><br/>
                                </td>
                                <td style={{'textAlign': 'right'}} className="stat-td">
                                    <label className="left">aft </label>
                                    <select name="aft" value={this.props.settings.aft} onChange={ this.handleChange }>
                                        <option value="0">Any</option>
                                        <option value="1">Tagged only</option>
                                        <option value="2">Untagged only</option>
                                    </select><br/>

                                    <label className="left">blockstate </label>
                                    <select name="blockstate" value={this.props.settings.blockstate} onChange={ this.handleChange }>
                                        <option value="0">Forwarding</option>
                                        <option value="1">Blocked</option>
                                        <option value="2">Learn only</option>
                                    </select><br/>
                                    <label className="left">untag_from_btable </label>
                                    <input
										type="number"
										min="0"
										max="1"
                                        value={this.props.settings.untag_from_btable}
                                        name="untag_from_btable"
                                        onChange={ this.handleChange }
                                        required
                                    /><br/>
                                </td>
                            </tr>
                            <tr>
                                <td colSpan="2">
                                    <input type="submit" onClick={ this.handleSubmit }/>
                                </td>
                            </tr>
                        </tbody>
                    </table>
                </div>
            </form>
        )
    }

}

class PortSettings extends React.Component {

    constructor(props) {
        super(props);
        this.state = {isLoading: true, activePort: 1};
    }

    handleSubmit = (port) => {
        fetch(
            apiUrls.port_settings,
            {
                method: 'POST',
                credentials: 'include',
                body: JSON.stringify(this.state.portSettList[port - 1]),
                headers: {
                    'X-CSRFToken': getCSRF(),
                    'content-type': 'application/json',
                }
            }).then(
            body => body.json(),
        ).then(
            json => {
                console.log(json);
                this.load();
            }
        );
    };

    load = () => {
        fetch(
            apiUrls.port_settings,
            { credentials: 'include' }
        ).then(
            (body) => body.json()
        ).then(
            (json) => {
                return this.setState({isLoading: false, portSettList: json});
            }
        );
    };

    componentDidMount(){
        this.load();
    }

    componentDidUpdate(){
        ReactDOM.render(
            <div className="switcher">
                <Switcher
                    name="Port"
                    entriesNumber={16}
                    startPoint={1}
                    activePort={this.state.activePort}
                    setActive={this.setActive}
                />
            </div>,
            document.getElementById('id_menu'),
        );
    }

    setActive = (port) => {
        this.setState({activePort: port});
    };

    handleChange = (port, settList) => {
        let prevState = this.state;
        prevState.portSettList[port - 1] = settList;
        this.setState(prevState)
    };

    render() {
        if (this.state.isLoading) {
            return (
                <div> <img src={ Loading } className={'loading-img'} id={this.props.name + 'loading-img'}/></div>
            );
        }

        return (
            <OnePortSettings
                activePort={this.state.activePort}
                settings={this.state.portSettList[this.state.activePort - 1]}
                onChange={this.handleChange}
                onClick={this.handleSubmit}
            />
        )
    }

}



ReactDOM.render(
    <PortSettings />,
    document.getElementById('id_content'),
);
