import React from 'react';
import ReactDOM from 'react-dom';

import apiUrls from '../../apiUrls';

import Switcher from './Switcher.jsx';
import Loading from '../loading.gif';

// Queue: 2
// curQ_pck_cnt[31:0]: 0
// curQ_drop_cnt[31:0]: 0
// curQ_trm_cnt[31:0]: 0
// settings curQ_Qmax[8:0]: 0
// settings curQ_Qmin[8:0]: 0
// settings curQ_cfg[1:0]: 0
// curQ_hw_prob_cfg_tbl0[31:0]: 0x00000000
// curQ_hw_prob_cfg_tbl1[31:0]: 0x00000000

class Queue extends React.Component {

    handleChange = (e) => {
        this.props.onChange(e, this.props['queue'])
    };

    handleReset = (e) => {
        e.preventDefault();
        this.props.onReset(e);
    };

    render() {
        return (
            <div className={"queue-settings"}>
                <fieldset>
                    <legend>Queue { this.props.queue } settings</legend>
                    <table>
                        <tbody>
                            <tr>
                                <td className="stat-td" style={{'textAlign': 'right'}}>
                                    <label className="left">Queue weight: </label>
                                    <input
                                        type="number"
                                        min="1"
                                        max="4294967295"
                                        value={ this.props.settings['Queue weight'] }
                                        name="Queue weight"
										onChange={ this.handleChange }
										required
                                    />
                                    <br/>

                                    <label className="left">Scheduler number: </label>
                                    <select name="Scheduler number" value={this.props.settings['Scheduler number'] } onChange={ this.handleChange }>
                                        <option value="0">Not connected</option>
                                        <option value="1">Scheduler 1</option>
                                        <option value="2">Scheduler 2</option>
                                    </select><br/>

									<label className="left">Scheduler input: </label>
                                    <input
                                        type="number"
                                        min="1"
                                        max="8"
                                        value={ this.props.settings['Scheduler input'] }
                                        name="Scheduler input"
										onChange={ this.handleChange }
										required
                                    />
                                    <br/>

                                    <label className="left">Queue management </label>
                                    <select name="Queue management" value={this.props.settings['Queue management'] } onChange={ this.handleChange }>
                                        <option value="0">Unmanaged</option>
                                        <option value="1">Tail drop </option>
                                        <option value="2">WRED </option>
                                    </select><br/>

                                    <label className="left">Max queue size </label>
                                    <input
										type="number"
										min="0"
										max="512"
                                        value={ this.props.settings['Max queue size'] }
                                        name="Max queue size"
										onChange={ this.handleChange }
										required
                                    /><br/>

                                    <label className="left">Min queue size </label>
                                    <input
										type="number"
										min="0"
                                        max="512"
                                        value={ this.props.settings['Min queue size'] }
                                        name="Min queue size"
										onChange={ this.handleChange }
										required
                                    /><br/>

									<label className="left">Queue tx counter:  { this.props.settings['Queue tx counter'] === undefined ? "" : this.props.settings['Queue tx counter']}</label>
                                    <br/>

                                    <label className="left">Queue drop counter: { this.props.settings['Queue drop counter'] === undefined ? "" : this.props.settings['Queue drop counter']}</label>
                                    <br/>

                                    <label className="left">Queue pck counter: { this.props.settings['Queue pck counter'] === undefined ? "" : this.props.settings['Queue pck counter']}</label>
                                    <br/>
                                </td>
                            </tr>
                            <tr>
                                <td colSpan="2">
									<input type="submit" name="Queue tx counter" onClick={this.handleReset} value="Reset counters"/>
                                    <input type="submit" onClick={ this.props.onSubmit }/>
                                </td>
                            </tr>
                        </tbody>
                    </table>
                </fieldset>
            </div>
        )
    }
}

class OnePortSettings extends React.Component {

    handleChange = (e, queueNum) => {
        e.target.className += (e.target.classList.contains('changed') ?  '' : 'changed');

        let port = this.props.activePort;
        let settings = this.props.settings;

        settings[queueNum - 1][e.target.name] = e.target.value;
        this.props.onChange(port, settings);
    };

    handleReset = (e) => {
        this.props.onReset(this.props.activePort, this.props.activeQueue, e.target.name);
    };

    handleSubmit = (e) => {
        e.preventDefault();
        this.props.onClick(this.props.activePort, this.props.activeQueue);
        this.isValid(e);
    };

    isValid = (e) => {
        let elems = e.target.form.getElementsByClassName('changed');
        let validity = true;
        for (let i = 0; i < elems.length; i++){
            if(!elems[i].validity.valid){
                validity = false;
            }
        }
        console.log(elems);
        if (!validity) {
            alert('You have invalid fields!');
            return false;
        }
        return true;
    };

    render() {
        return (
            <form method="POST">
                <div className="port-settings" align="center">
                    <Queue
                        queue={ this.props.activeQueue}
                        settings={ this.props.settings[this.props.activeQueue - 1]}
                        onSubmit={ this.handleSubmit }
                        onReset={ this.handleReset }
                        onChange={ this.handleChange }/>
                </div>
            </form>
        )
    }

}

class QueueSettings extends React.Component {

    constructor(props) {
        super(props);
        this.state = {isLoading: true, activePort: 1, activeQueue: 1};
    }

    handleSubmit = (port, queue) => {
        let toSend = this.state.queue_settings[port - 1].settings[queue - 1];

        toSend['PORT_ID'] = port;
        toSend['RESET_F'] = false;
        console.log(toSend);
        fetch(
            apiUrls.queue_settings,
            {
                method: 'POST',
                credentials: 'include',
                body: JSON.stringify(toSend),
                headers: {
                    'X-CSRFToken': getCSRF(),
                    'content-type': 'application/json',
                }
            }).then(
            body => body.json(),
        ).then(
            json => {
                console.log(json);
                this.load();
            }
        );
    };

    handleReset = (port, queue, name) => {
        let toSend = this.state.queue_settings[port - 1].settings[queue - 1];
        toSend[name] = '-1';

        toSend['PORT_ID'] = port;
        toSend['RESET_F'] = true;
        console.log(toSend);
        fetch(
            apiUrls.queue_settings,
            {
                method: 'POST',
                credentials: 'include',
                body: JSON.stringify(toSend),
                headers: {
                    'X-CSRFToken': getCSRF(),
                    'content-type': 'application/json',
                }
            }).then(
            body => body.json(),
        ).then(
            json => {
                console.log(json);
                this.load();
            }
        );
    };

    load = () => {
        fetch(
            apiUrls.queue_settings,
            { credentials: 'include' }
        ).then(
            body => {
                return body.json();
            }
        ).then(
            (json) => {
                console.log(json);
                return this.setState({isLoading: false, queue_settings: json });
            }
        );
    };

    componentDidMount(){
        this.load();
    }

    componentDidUpdate(){
        ReactDOM.render(
            <div>
                <Switcher name="Port" entriesNumber={16} startPoint={1} activePort={this.state.activePort} setActive={this.setActiveP}/>
                <Switcher name="Queue" entriesNumber={8} startPoint={1} activePort={this.state.activeQueue} setActive={this.setActiveQ}/>
            </div>,
            document.getElementById('id_menu'),
        );
    }

    setActiveP = (port) => {
        this.setState({activePort: port});
    };
    setActiveQ = (queue) => {
        this.setState({activeQueue: queue});
    };

    handleChange = (port, settList) => {
        let prevState = this.state;
        prevState.queue_settings[port - 1].settings = settList;
        this.setState(prevState)
    };

    render() {
        if (this.state.isLoading) {
            return (
                <div> <img src={ Loading } className={'loading-img'} id={this.props.name + 'loading-img'}/></div>
            );
        }

        return (
            <div>
                <OnePortSettings
                    activePort={this.state.activePort}
                    activeQueue={this.state.activeQueue}
                    settings={this.state.queue_settings[this.state.activePort - 1].settings}
                    onChange={this.handleChange}
                    onClick={this.handleSubmit}
                    onReset={this.handleReset}
                />
            </div>
        )
    }

}

ReactDOM.render(
    <QueueSettings />,
    document.getElementById('id_content'),
);
