import React from 'react';
import ReactDOM from 'react-dom';

import apiUrls from '../../apiUrls'

import Switcher from './Switcher.jsx'
import Loading from '../loading.gif';

// scheduler algo type: 3
// Queue 0 weight: 1280
// Queue 1 weight: 1280
// Queue 2 weight: 0
// Queue 3 weight: 0
// Queue 4 weight: 1280
// Queue 5 weight: 1280
// Queue 6 weight: 1280
// Queue 7 weight: 1280
// Queue 0-3 Allocation: 0x8080100
// Queue 4-7 Allocation: 0x7060504
// Bit/packet Rate: 0
// Sch2 queue number to which Sch1 is mapped: 0

// class LabeledField extends ReactComponent {
// 	return ()
// }

class Scheduler extends React.Component {

    handleChange = (e) => {
        this.props.onChange(e, this.props['schedule_id'])
    };

    render() {
		var arr = [];
		let shd1fs;
        for (let i = 0; i <= 7; i++) {
            arr[i] = i;
		}
		if (this.props['schedule_id'] == 1)
			shd1fs = 
			<div>
				<label className="left">Input Sh1 -> Sh2</label>
				<input
					type="number"
					min="1"
					max="8"
					value={ this.props.settings['Sch2 input to which Sch1 is going'] }
					name="Sch2 input to which Sch1 is going"
					onChange={ this.handleChange }
					required
				/>
				<br/>
				<label className="left">Weight of connected queue </label>
				<input
					type="number"
                    min="1"
                    max="4294967295"
					value={ this.props.settings['Weight queue of Sch2 input which Sch1 is going'] }
					name="Weight queue of Sch2 input which Sch1 is going"
					onChange={ this.handleChange }
					required
				/>
				<br/>
			</div>;
		else
			shd1fs = <div><br /><br /></div>;
        return (
                <fieldset>
                    <legend>Scheduler { this.props['schedule_id'] } settings</legend>
                    <label className="left">Algorithm type </label>
                    <select name="Scheduler algo type" value={ this.props.settings['Scheduler algo type']} onChange={ this.handleChange }>
                        <option value="1">PQ</option>
                        <option value="3">DWRR</option>
                        <option value="4">RR</option>
                        <option value="5">WRR</option>
                    </select><br />

                    { shd1fs != null && shd1fs }
					{/* <br/>
                    <label className="left">Queue 4-7 Allocation </label>
                    <input
                        pattern="^0x([0-9a-fA-F]|0[0-9a-fA-F])(0[0-9a-fA-F]){3}$"
                        value={ this.props.settings['Queue 4-7 Allocation'] }
                        name="Queue 4-7 Allocation"
                        onChange={ this.handleChange }
                        required
                    /><br/> */}

                </fieldset>
        )
    }
}

class OnePortSettings extends React.Component {

    handleChange = (e, scheduleNum) => {
        e.target.className += (e.target.classList.contains('changed') ?  '' : 'changed');

        let port = this.props.activePort;
        let settings = this.props.settings;

        settings[scheduleNum - 1][e.target.name] = e.target.value;
        this.props.onChange(port, settings);
    };

    handleSubmit  = (e) => {
        e.preventDefault();
        if (this.isValid(e)) {
            this.props.onClick(this.props.activePort);
        }
    };

    isValid = (e) => {
        let elems = e.target.form.getElementsByClassName('changed');
        let validity = true;
        for (let i = 0; i < elems.length; i++){
            if(!elems[i].validity.valid){
                validity = false;
            }
        }
        console.log(elems);
        if (!validity) {
            alert('You have invalid fields!');
            return false;
        }
        return true;
    };

    render() {
        return (
            <form method="POST">
                <div align="center">
                    <table>
                        <tbody>
                            <tr>
                                <td style={{'textAlign': 'right'}}>
                                    <Scheduler schedule_id="1" settings={this.props.settings[0]} onChange={ this.handleChange }/>
                                </td>
                                <td style={{'textAlign': 'right'}}>
                                    <Scheduler schedule_id="2" settings={this.props.settings[1]} onChange={ this.handleChange }/>
                                </td>
                            </tr>
                            <tr><td colSpan="2"><input type="submit" onClick={ this.handleSubmit }/></td></tr>
                        </tbody>
                    </table>
                </div>
            </form>
        )
    }

}

class SchedulerSettings extends React.Component {

    constructor(props) {
        super(props);
        this.state = {isLoading: true, activePort: 1};
    }

    handleSubmit = (port) => {
        fetch(
            apiUrls.scheduler_settings,
            {
                method: 'POST',
                credentials: 'include',
                body: JSON.stringify(this.state.scheduler_settings[port - 1]),
                headers: {
                    'X-CSRFToken': getCSRF(),
                    'content-type': 'application/json',
                }
            }).then(
            body => body.json(),
        ).then(
            json => {
                console.log(json);
                this.load();
            }
        );
    };

    load = () => {
        fetch(
            apiUrls.scheduler_settings,
            { credentials: 'include' }
        ).then(
            (body) => body.json()
        ).then(
            (json) => {
                return this.setState({isLoading: false, scheduler_settings: json});
            }
        );
    };

    componentDidMount(){
        this.load();
    }

    componentDidUpdate(){
        ReactDOM.render(
            <div className="switcher">
                <Switcher name="Port" entriesNumber={16} startPoint={1} activePort={this.state.activePort} setActive={this.setActive}/>
            </div>,
            document.getElementById('id_menu'),
        );
    }

    setActive = (port) => {
        this.setState({activePort: port});
    };

    handleChange = (port, settList) => {
        let prevState = this.state;
        prevState.scheduler_settings[port - 1].settings = settList;
        this.setState(prevState)
    };

    render() {
        if (this.state.isLoading) {
            return (
                <div> <img src={ Loading } className={'loading-img'} id={this.props.name + 'loading-img'}/></div>
            );
        }

        return (
            <div>
                <OnePortSettings
                    activePort={this.state.activePort}
                    settings={this.state.scheduler_settings[this.state.activePort - 1].settings}
                    onChange={this.handleChange}
                    onClick={this.handleSubmit}/>
            </div>
        )
    }

}

ReactDOM.render(
    <SchedulerSettings />,
    document.getElementById('id_content'),
);
