import React from 'react';
import ReactDOM from 'react-dom';

import apiUrls from '../../apiUrls'

import Switcher from './Switcher.jsx'
import Loading from '../loading.gif';

// shaper: 1
// enable: 1
// clk_div: 9
// weight frac: 1536
// weight int: 156
// max credit: 4294443008
// min credit: 4193792
// bit/packet rate: 0
// queue position: 8
// shaper mode: 1


const reload = ['curQ_pck_cnt[31:0]', 'curQ_drop_cnt[31:0]', 'curQ_trm_cnt[31:0]'];

class Shaper extends React.Component {

    handleChange = (e) => {
        this.props.onChange(e, this.props['shaper'])
    };

    render() {
        return (
            <div className={"queue-settings"}>
                <fieldset>
                    <legend>Shaper { this.props.shaper } settings</legend>

                    <label className="left">Enable </label>
                    <select name="Enable" value={this.props.settings['Enable']} onChange={ this.handleChange }>
                        <option value="1">Enabled</option>
                        <option value="0">Disabled </option>
                    </select><br/>

                    <label className="left">Mode </label>
					<select name="Mode" value={this.props.settings['Mode']} onChange={ this.handleChange }>
                        <option value="0">Zero burst</option>
                        <option value="1">Bursty</option>
                    </select><br/>

                    <label className="left">Position </label>
                    <select name="Position" value={this.props.settings['Position']} onChange={ this.handleChange }>
                        <option value="1">Scheduler 2 output</option>
                        <option value="2">Scheduler 2 input 1 or Scheduler 1 output*</option>
                        <option value="3">Scheduler 2 input 2</option>
                        <option value="4">Scheduler 2 input 3</option>
                        <option value="5">Scheduler 2 input 4</option>
                        <option value="6">Scheduler 2 input 5</option>
                        <option value="7">Scheduler 2 input 6</option>
                        <option value="8">Scheduler 2 input 7</option>
                        <option value="9">Scheduler 2 input 8</option>
                        <option value="10">Scheduler 1 input 1</option>
                        <option value="11">Scheduler 1 input 2</option>
                        <option value="12">Scheduler 1 input 3</option>
                        <option value="13">Scheduler 1 input 4</option>
                        <option value="14">Scheduler 1 input 5</option>
                        <option value="15">Scheduler 1 input 6</option>
                        <option value="16">Scheduler 1 input 7</option>
                        <option value="17">Scheduler 1 input 8</option>
                    </select>
					<br/>
					
                    <label className="left">Rate units </label>
                    <select value={ this.props.settings['Rate units'] } name="Rate units" onChange={ this.handleChange }>
						<option value="1">Kbit/s</option>
						<option value="2">Packets/s</option>
					</select>
					<br/>

                    <label className="left">Rate </label>
                    <input
						type="number"
						min="0"
						max="1000000"
						value={ this.props.settings['Rate'] }
						name="Rate"
						onChange={ this.handleChange }
						required
					/>
					<br/>

                    <label className="left">Min credit </label>
					<input
						type="number"
						value={ this.props.settings['Min credit'] } 
						name="Min credit" 
						min="0"
						max="4193792"
						onChange={ this.handleChange }
						required
					/>
					<br/>

                    <label className="left">Max credit </label>
					<input
						type="number"
						value={ this.props.settings['Max credit'] }
						name="Max credit"
						min="0"
						max="4193792"
						onChange={ this.handleChange }
						required
					/><br/>

                </fieldset>
            </div>
        )
    }
}

class OnePortSettings extends React.Component {

    handleChange = (e, shaperNum) => {
        e.target.className += (e.target.classList.contains('changed') ?  '' : 'changed');

        let port = this.props.activePort;
        let settings = this.props.settings;

        settings[shaperNum - 1][e.target.name] = e.target.value;
        this.props.onChange(port, settings);
    };

    handleSubmit  = (e) => {
        e.preventDefault();
        this.isValid(e);
        this.props.onClick(this.props.activePort, this.props.activeShaper);
    };

    isValid = (e) => {
        let elems = e.target.form.getElementsByClassName('changed');
        let validity = true;
        for (let i = 0; i < elems.length; i++){
            if(!elems[i].validity.valid){
                validity = false;
            }
        }
        console.log(elems);
        if (!validity) {
            alert('You have invalid fields!');
            return false;
        }
        return true;
    };

    render() {
        return (
            <form method="POST">
                <div align="center">
                    <table>
                        <tbody>
                        <tr>
                            <td style={{'textAlign': 'right'}}>
                                <Shaper shaper={ this.props.activeShaper } settings={ this.props.settings[this.props.activeShaper - 1]} onChange={this.handleChange}/>
                            </td>
                        </tr>
                        <tr>
                            <td colSpan="2">
                                <input type="submit" onClick={ this.handleSubmit }/>
                            </td>
                        </tr>
                        </tbody>
                    </table>
                </div>
            </form>
        )
    }

}

class ShaperSettings extends React.Component {

    constructor(props) {
        super(props);
        this.state = {isLoading: true, activePort: 1, activeShaper: 1};
    }

    handleSubmit = (port, shaper) => {
        let toSend = this.state.shaper_settings[port - 1].settings[shaper - 1];

        toSend['PORT_ID'] = port;
        console.log(toSend);
        fetch(
            apiUrls.shaper_settings,
            {
                method: 'POST',
                credentials: 'include',
                body: JSON.stringify(toSend),
                headers: {
                    'X-CSRFToken': getCSRF(),
                    'content-type': 'application/json',
                }
            }).then(
            body => body.json(),
        ).then(
            json => {
                console.log(json);
                this.load();
            }
        );
    };

    load = () => {
        fetch(
            apiUrls.shaper_settings,
            { credentials: 'include' }
        ).then(
            body => {
                return body.json();
            }
        ).then(
            (json) => {
                console.log(json);
                return this.setState({isLoading: false, shaper_settings: json });
            }
        );
    };

    componentDidMount(){
        this.load();
    }

    componentDidUpdate(){
        ReactDOM.render(
            <div>
                <Switcher name="Port" entriesNumber={16} startPoint={1} activePort={this.state.activePort} setActive={this.setActiveP}/>
                <Switcher name="Shaper" entriesNumber={4} startPoint={1} activePort={this.state.activeShaper} setActive={this.setActiveS}/>
            </div>,
            document.getElementById('id_menu'),
        );
    }

    setActiveP = (port) => {
        this.setState({activePort: port});
    };
    setActiveS = (shaper) => {
        this.setState({activeShaper: shaper});
    };

    handleChange = (port, settList) => {
        let prevState = this.state;
        prevState.shaper_settings[port - 1].settings = settList;
        this.setState(prevState)
    };

    render() {
        if (this.state.isLoading) {
            return (
                <div> <img src={ Loading } className={'loading-img'} id={this.props.name + 'loading-img'}/></div>
            );
        }

        return (
            <div>
                <OnePortSettings
                    activePort={this.state.activePort}
                    activeShaper={this.state.activeShaper}
                    settings={this.state.shaper_settings[this.state.activePort - 1].settings}
                    onChange={this.handleChange}
                    onClick={this.handleSubmit}/>
            </div>
        )
    }

}

ReactDOM.render(
    <ShaperSettings />,
    document.getElementById('id_content'),
);
