import React from 'react';
import ReactDOM from 'react-dom';

import apiUrls from '../../apiUrls'

import Popup from "./Popup.jsx";
import Loading from '../loading.gif';

class VlanRecord extends React.Component {
    render(){
        return (
            <tbody>
                <tr align="center">
                    <td>{ this.props.index }</td>
                    <td>{ this.props.item.VLANID }</td>
                    <td>{ this.props.item.Forwardlist }</td>
                    <td>{ this.props.item.Untaglist }</td>
                    <td>{ this.props.item.UnicastHit }</td>
                    <td>{ this.props.item.UnicastMiss }</td>
                    <td>{ this.props.item.MulticastHit }</td>
                    <td>{ this.props.item.MulticastMiss }</td>
                    <td>{ this.props.item.Mstp }</td>
                    <td><button onClick={ this.props.onDelete } name={ this.props.item.VLANID }> </button></td>
                </tr>
            </tbody>
        )
    }
}

class VlanTable extends React.Component {

    constructor(props){
        super(props);
        this.state = {
            isLoading: true,
        }
    }


    deleteAll = (isOk, e) => {
        if(isOk === true){
            let bodyStr = '{"DELETE_ID": ' + (e === undefined ? "-1" : e.name )+ '}';
            console.log(bodyStr);
            fetch(
                apiUrls.vlans,
                {
                    method: 'POST',
                    credentials: 'include',
                    body: bodyStr,
                    headers: {
                        'X-CSRFToken': getCSRF(),
                        'content-type': 'application/json',
                    }
                }).then(
                body => body.json(),
            ).then(
                (json) => {
                    console.log(json);
                    this.setState({isLoading: true});
                    this.load()
                }
            );
        }
    };

    onDelete = (e) => {
        let isOk = false;
        if (e.target.name === '-1') {
            isOk = confirm('Delete ALL VLAN entries?');
            this.deleteAll(isOk);
        } else {
            isOk = confirm('Delete entry with VLAN: ' + e.target.name + '?');
            this.deleteAll(isOk, e.target);
        }
    };

    load = () => {
        fetch(
            apiUrls.vlans,
            { credentials: 'include' }
        ).then(
            (body) => body.json()
        ).then(
            (json) => {
                console.log(json);
                return this.setState({isLoading: false, vlanList: json});
            }
        );
    };

    componentDidMount(){
        this.load();
    }

    render(){
        if (this.state.isLoading) {
            return (
                <div> <img src={ Loading } className={'loading-img'} id={this.props.name + 'loading-img'}/></div>
            );
        }
        console.log(this.state.vlanList);
        if(!(
            typeof this.state.vlanList !== "undefined" &&
            this.state.vlanList !== null &&
            this.state.vlanList.length !== null &&
            this.state.vlanList.length > 0)
        ) {
            return (
                <div>Table is empty.</div>
            );
        }

        const vlans = this.state.vlanList.map(
            (item, index) => <VlanRecord index={index + 1}  key={ item.VLANID } item={ item } onDelete={ this.onDelete }/>
        );
        return (
            <div align="center">
                <table border="1">
                    <tbody>
                        <tr align="center">
                            <td style={{'minWidth': '25px'}}>#</td>
                            <td>Vlan ID</td>
                            <td>Forwardlist</td>
                            <td>Untaglist</td>
                            <td>UnicastHit</td>
                            <td>UnicastMiss</td>
                            <td>MulticastHit</td>
                            <td>MulticastMiss</td>
                            <td>Mstp</td>
                            <td>Delete</td>
                        </tr>
                    </tbody>
                    { vlans }
                </table>
                <button onClick={ this.onDelete } name="-1">Delete all</button>
            </div>
        );
    }
}


ReactDOM.render(
    <VlanTable />,
    document.getElementById('id_content'),
);
